#!/bin/bash
set -e

# check dependencies
count=0
for dependency in curl hxnormalize hxselect grep sed; do
	if [ ! -x "$(command -v $dependency)" ]; then
		echo "$dependency missing"
		count=$((count+1))
	fi
done

# exit script if any dependencies missing
if [ $count -ne 0 ]; then
	exit 1
fi

# upstream URL
UPSTREAM_URL="https://www.oilshell.org/release/latest/"


# options to pass to cURL, including custom user agent
USER_AGENT="oil-version-checker/1.0 george@rawlinson.net.nz"
CURL_OPTS=(--silent --user-agent "$USER_AGENT")

curl "${CURL_OPTS[@]}" "$UPSTREAM_URL" | \
	hxnormalize -x | \
	hxselect -c 'a' -s '\n' | \
	grep '.tar.gz' | \
	sed -e "s/^oil-//" -e "s/\.tar.gz$//"
exit 0
